@@ -117,6 +117,10 @@ class GnocchiDriver(drivers.Driver):
             storage_config = {
                 "ceph_conffile": storage_parsed.path,
             }
+        elif storage_driver == "redis":
+            storage_config = {
+                "redis_url": self.storage_url,
+            }
         elif storage_driver == "file":
             storage_config = {
                 "file_basepath": (storage_parsed.path
@@ -176,7 +180,6 @@ url = %s""" % (storage_driver,
         self.putenv("URL", "gnocchi://localhost:%d" % self.port)
         self.putenv("GNOCCHI_HTTP_URL", self.http_url)
         self.putenv("GNOCCHI_ENDPOINT", self.http_url, True)
-        self.putenv("OS_AUTH_TYPE", "gnocchi-noauth", True)
+        self.putenv("OS_AUTH_TYPE", "gnocchi-basic", True)
         self.putenv("GNOCCHI_STATSD_RESOURCE_ID", statsd_resource_id, True)
-        self.putenv("GNOCCHI_USER_ID", "admin", True)
-        self.putenv("GNOCCHI_PROJECT_ID", "admin", True)
+        self.putenv("GNOCCHI_USER", "admin", True)
